If you notice any bugs, need any help, or want to contribute any code,
GitHub issues and pull requests are very welcome! All pull requests require
``black`` formatting, clean ``flake8``, and 100%
branch ``coverage``, with any ``pragma`` fully explained by comments. Contributions
are to be made under the terms of the LICENSE.